@@ -60,7 +60,7 @@ static GMainLoop *loop;
 		}							\
 	}G_STMT_END
 
-G_DEFINE_TYPE(EDataBookFactory, e_data_book_factory, G_TYPE_OBJECT);
+G_DEFINE_TYPE (EDataBookFactory, e_data_book_factory, G_TYPE_OBJECT);
 
 #define E_DATA_BOOK_FACTORY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), E_TYPE_DATA_BOOK_FACTORY, EDataBookFactoryPrivate))
 
@@ -323,18 +323,6 @@ impl_BookFactory_getBook (EGdbusBookFactory *object, GDBusMethodInvocation *invo
 
 	uri = e_source_get_uri (source);
 
-	if (!uri || !*uri) {
-		g_mutex_unlock (priv->backends_lock);
-		g_object_unref (source);
-		g_free (uri);
-
-		error = g_error_new (E_DATA_BOOK_ERROR, E_DATA_BOOK_STATUS_NO_SUCH_BOOK, _("Empty URI"));
-		g_dbus_method_invocation_return_gerror (invocation, error);
-		g_error_free (error);
-
-		return TRUE;
-	}
-
 	g_mutex_lock (priv->books_lock);
 	backend = g_hash_table_lookup (priv->backends, uri);
 
@@ -499,7 +487,7 @@ die (const gchar *prefix, GError *error)
 {
 	g_error("%s: %s", prefix, error->message);
 	g_error_free (error);
-	exit(1);
+	exit (1);
 }
 
 static void
@@ -571,6 +559,30 @@ on_name_lost (GDBusConnection *connection,
 	g_mutex_unlock (factory->priv->connections_lock);
 }
 
+#ifndef G_OS_WIN32
+static void
+quit_signal (gint sig)
+{
+	g_return_if_fail (sig == SIGQUIT);
+
+	g_print ("Received quit signal...\n");
+	g_main_loop_quit (loop);
+}
+
+static void
+setup_quit_signal (void)
+{
+	struct sigaction sa, osa;
+
+	sigaction (SIGQUIT, NULL, &osa);
+
+	sa.sa_flags = 0;
+	sigemptyset (&sa.sa_mask);
+	sa.sa_handler = quit_signal;
+	sigaction (SIGQUIT, &sa, NULL);
+}
+#endif
+
 gint
 main (gint argc, gchar **argv)
 {
@@ -626,7 +638,11 @@ main (gint argc, gchar **argv)
 	/* Migrate user data from ~/.evolution to XDG base directories. */
 	e_data_book_migrate ();
 
-	printf ("Server is up and running...\n");
+	#ifndef G_OS_WIN32
+	setup_quit_signal ();
+	#endif
+
+	g_print ("Server is up and running...\n");
 
 	g_main_loop_run (loop);
 
@@ -634,7 +650,7 @@ main (gint argc, gchar **argv)
 	g_object_unref (eol);
 	g_object_unref (factory);
 
-	printf ("Bye.\n");
+	g_print ("Bye.\n");
 
 	return 0;
 }
