@@ -63,6 +63,7 @@ static gssize
 seekable_substream_read (CamelStream *stream,
                          gchar *buffer,
                          gsize n,
+                         GCancellable *cancellable,
                          GError **error)
 {
 	CamelSeekableStream *parent;
@@ -90,7 +91,8 @@ seekable_substream_read (CamelStream *stream,
 		return 0;
 	}
 
-	v = camel_stream_read (CAMEL_STREAM (parent), buffer, n, error);
+	v = camel_stream_read (
+		CAMEL_STREAM (parent), buffer, n, cancellable, error);
 
 	/* ignore <0 - it's an error, let the caller deal */
 	if (v > 0)
@@ -103,11 +105,12 @@ static gssize
 seekable_substream_write (CamelStream *stream,
                           const gchar *buffer,
                           gsize n,
+                          GCancellable *cancellable,
                           GError **error)
 {
 	CamelSeekableStream *parent;
-	CamelSeekableStream *seekable_stream = CAMEL_SEEKABLE_STREAM(stream);
-	CamelSeekableSubstream *seekable_substream = CAMEL_SEEKABLE_SUBSTREAM(stream);
+	CamelSeekableStream *seekable_stream = CAMEL_SEEKABLE_STREAM (stream);
+	CamelSeekableSubstream *seekable_substream = CAMEL_SEEKABLE_SUBSTREAM (stream);
 	gssize v;
 
 	if (n == 0)
@@ -130,7 +133,8 @@ seekable_substream_write (CamelStream *stream,
 		return 0;
 	}
 
-	v = camel_stream_write (CAMEL_STREAM (parent), buffer, n, error);
+	v = camel_stream_write (
+		CAMEL_STREAM (parent), buffer, n, cancellable, error);
 
 	/* ignore <0 - it's an error, let the caller deal */
 	if (v > 0)
@@ -142,15 +146,18 @@ seekable_substream_write (CamelStream *stream,
 
 static gint
 seekable_substream_flush (CamelStream *stream,
+                          GCancellable *cancellable,
                           GError **error)
 {
 	CamelSeekableSubstream *sus = (CamelSeekableSubstream *)stream;
 
-	return camel_stream_flush (CAMEL_STREAM (sus->parent_stream), error);
+	return camel_stream_flush (
+		CAMEL_STREAM (sus->parent_stream), cancellable, error);
 }
 
 static gint
 seekable_substream_close (CamelStream *stream,
+                          GCancellable *cancellable,
                           GError **error)
 {
 	/* we dont really want to close the substream ... */
@@ -160,8 +167,8 @@ seekable_substream_close (CamelStream *stream,
 static gboolean
 seekable_substream_eos (CamelStream *stream)
 {
-	CamelSeekableSubstream *seekable_substream = CAMEL_SEEKABLE_SUBSTREAM(stream);
-	CamelSeekableStream *seekable_stream = CAMEL_SEEKABLE_STREAM(stream);
+	CamelSeekableSubstream *seekable_substream = CAMEL_SEEKABLE_SUBSTREAM (stream);
+	CamelSeekableStream *seekable_stream = CAMEL_SEEKABLE_STREAM (stream);
 	CamelSeekableStream *parent;
 	gboolean eos;
 
@@ -276,7 +283,7 @@ camel_seekable_substream_init (CamelSeekableSubstream *seekable_substream)
  * Returns: the substream
  **/
 CamelStream *
-camel_seekable_substream_new(CamelSeekableStream *parent_stream, goffset start, goffset end)
+camel_seekable_substream_new (CamelSeekableStream *parent_stream, goffset start, goffset end)
 {
 	CamelSeekableSubstream *seekable_substream;
 
